# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from yfkm3_services_search_client.models.search_mode import SearchMode
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class DatasetSyncEvalRequest(BaseModel):
    """
    DatasetSyncEvalRequest
    """ # noqa: E501
    space_id: StrictInt
    collection_ids: Optional[List[StrictInt]] = None
    mode: Optional[SearchMode] = None
    top_k: Optional[StrictInt] = 5
    with_rerank: Optional[StrictBool] = False
    rerank_top_n: Optional[StrictInt] = None
    is_active: Optional[StrictBool] = None
    limit: Optional[StrictInt] = None
    run_name: Optional[StrictStr] = None
    sync_to_langfuse: Optional[StrictBool] = True
    __properties: ClassVar[List[str]] = ["space_id", "collection_ids", "mode", "top_k", "with_rerank", "rerank_top_n", "is_active", "limit", "run_name", "sync_to_langfuse"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DatasetSyncEvalRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if rerank_top_n (nullable) is None
        # and model_fields_set contains the field
        if self.rerank_top_n is None and "rerank_top_n" in self.model_fields_set:
            _dict['rerank_top_n'] = None

        # set to None if is_active (nullable) is None
        # and model_fields_set contains the field
        if self.is_active is None and "is_active" in self.model_fields_set:
            _dict['is_active'] = None

        # set to None if limit (nullable) is None
        # and model_fields_set contains the field
        if self.limit is None and "limit" in self.model_fields_set:
            _dict['limit'] = None

        # set to None if run_name (nullable) is None
        # and model_fields_set contains the field
        if self.run_name is None and "run_name" in self.model_fields_set:
            _dict['run_name'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DatasetSyncEvalRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "space_id": obj.get("space_id"),
            "collection_ids": obj.get("collection_ids"),
            "mode": obj.get("mode"),
            "top_k": obj.get("top_k") if obj.get("top_k") is not None else 5,
            "with_rerank": obj.get("with_rerank") if obj.get("with_rerank") is not None else False,
            "rerank_top_n": obj.get("rerank_top_n"),
            "is_active": obj.get("is_active"),
            "limit": obj.get("limit"),
            "run_name": obj.get("run_name"),
            "sync_to_langfuse": obj.get("sync_to_langfuse") if obj.get("sync_to_langfuse") is not None else True
        })
        return _obj


