# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.dataset_sync_eval_response import DatasetSyncEvalResponse

class TestDatasetSyncEvalResponse(unittest.TestCase):
    """DatasetSyncEvalResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DatasetSyncEvalResponse:
        """Test DatasetSyncEvalResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DatasetSyncEvalResponse`
        """
        model = DatasetSyncEvalResponse()
        if include_optional:
            return DatasetSyncEvalResponse(
                dataset_name = '',
                total_items = 56,
                succeeded = 56,
                failed = 56,
                run_name = '',
                summary = { },
                items = [
                    { }
                    ]
            )
        else:
            return DatasetSyncEvalResponse(
                dataset_name = '',
                total_items = 56,
                succeeded = 56,
                failed = 56,
                summary = { },
                items = [
                    { }
                    ],
        )
        """

    def testDatasetSyncEvalResponse(self):
        """Test DatasetSyncEvalResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
